@@ -34,8 +34,11 @@ length(eh)
 mm <- query(eh, "mus musculus")
 mm
 
-## ----display, eval=FALSE------------------------------------------------------
-#  d <- display(eh)
+## ----BiocHubsShiny, eval=FALSE------------------------------------------------
+#  BiocHubsShiny::BiocHubsShiny()
+
+## ----echo=FALSE,fig.cap="BiocHubsShiny query with species term 'musculus'",out.width="100%"----
+knitr::include_graphics("mm10_BiocHubsShiny.png")
 
 ## ----dm2----------------------------------------------------------------------
 apData
